@@ -23,7 +23,8 @@ def inspect_certificate(cert: x509) -> dict:
     common_name = name_attrs[0].value if name_attrs else ""
 
     fingerprint_bytes = cert.fingerprint(hashes.SHA256())
-    fingerprint = base64.urlsafe_b64encode(fingerprint_bytes).decode()
+    fingerprint = f"SHA256:{fingerprint_bytes.hex().zfill(64).upper()}"
+    fingerprint_b64 = base64.urlsafe_b64encode(fingerprint_bytes).decode()
 
     not_before = cert.not_valid_before.strftime("%Y-%m-%dT%H:%M:%SZ")
     not_after = cert.not_valid_after.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -33,6 +34,7 @@ def inspect_certificate(cert: x509) -> dict:
     data = {
         "common_name": common_name,
         "fingerprint": fingerprint,
+        "fingerprint_b64": fingerprint_b64,
         "not_before": not_before,
         "not_after": not_after,
         "serial_number": serial_number,
